// SerialControl.h

#ifndef _SERIALCONTROL_h
#define _SERIALCONTROL_h

#include <Arduino.h>

typedef void (*Callback)();         // Funktionszeiger auf Funktionen vom Typ void function(void)
typedef void (*UintCallback)(uint); // Funktionszeiger auf Funktionen vom Typ void function(uint)


class SerialControl {
public:

   // Initialisiert die Klasseninstanz
   //    timerControl: Callback fr Kommando 't'
   //    countControl: Callback fr Kommando 'c'
   //    doSample:     Callback fr Kommando 's'
   //    doReset:      Callback fr Kommando 'r'
   SerialControl(Callback doSample, UintCallback timerControl, UintCallback countControl, Callback doReset)
      : doSample(doSample), timerControl(timerControl), countControl(countControl), doReset(doReset) {}

   // Initilaisiert die serielle Schnittstelle. Eine Baudrate ist bei der USB-Schnittstelle nicht notwendig.
   void begin();  

   // Prft den Input-Stream auf Kommandos
   void handle(); 

   // Weiterleitung der bentigten 'print..'-Methoden
   size_t println(const char c[]) { return Serial.println(c); }
   size_t print(const char c[]) { return Serial.print(c); }
   size_t println(int val, int base = DEC) { return Serial.println(val, base); }
   size_t print(int val, int base = DEC) { return Serial.print(val, base); }
   size_t println(double n, int digits) { return Serial.println(n, digits); }
   size_t print(double n, int digits) { return Serial.print(n, digits); }

protected:
   Callback doSample;        // Callback fr Kommando 's'
   UintCallback timerControl; // Callback fr Kommando 't'
   UintCallback countControl; // Callback fr Kommando 'c'
   Callback doReset;          // Callback fr Kommando 'r'

};
#endif